==> was-plugin-1.2.1-sources.jar: com/xebialabs/deployit/plugin/was/step/WasStopApplicationStep.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of Xebialabs Software and Documentation is subject to the Personal
 * License Agreement.
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * ‚ÄúDocumentation‚Äù means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the Xebialabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.was.step;

import com.xebialabs.deployit.ci.artifact.Ear;
import com.xebialabs.deployit.ci.artifact.EjbJar;
import com.xebialabs.deployit.ci.artifact.NamedDeployableArtifact;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.plugin.was.ci.WasCluster;

/**
 * Stops a {@link NamedDeployableArtifact application} on a {@link WasCluster} 
 */
@SuppressWarnings("serial")
public class WasStopApplicationStep extends ControlApplicationStep {

	private static final String STOP_APPLICATION = "stopApplication";

	public WasStopApplicationStep(WasCluster cluster, Ear ear) {
		super(cluster, (NamedDeployableArtifact) ear, STOP_APPLICATION);
	}

	public WasStopApplicationStep(WasCluster cluster, War war) {
		super(cluster, (NamedDeployableArtifact) war, STOP_APPLICATION);
	}

	public WasStopApplicationStep(WasCluster cluster, EjbJar ejbJar) {
		super(cluster, (NamedDeployableArtifact) ejbJar, STOP_APPLICATION);
	}
}

==> was-plugin-1.2.2-sources.jar: com/xebialabs/deployit/plugin/was/step/WasStopApplicationStep.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.was.step;

import com.xebialabs.deployit.ci.artifact.Ear;
import com.xebialabs.deployit.ci.artifact.EjbJar;
import com.xebialabs.deployit.ci.artifact.NamedDeployableArtifact;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.plugin.was.ci.WasCluster;
import com.xebialabs.deployit.plugin.was.ci.WasServer;

/**
 * Stops a {@link NamedDeployableArtifact application} on a {@link WasCluster}
 */
@SuppressWarnings("serial")
public class WasStopApplicationStep extends ControlApplicationStep {

	private static final String STOP_APPLICATION_COMMAND = "stopApplication";

	private static final String STOP_APPLICATION_DESCRIPTION = "Stop application";

	public WasStopApplicationStep(WasCluster cluster, Ear ear) {
		super(cluster, (NamedDeployableArtifact) ear, STOP_APPLICATION_COMMAND, STOP_APPLICATION_DESCRIPTION);
	}

	public WasStopApplicationStep(WasCluster cluster, War war) {
		super(cluster, (NamedDeployableArtifact) war, STOP_APPLICATION_COMMAND, STOP_APPLICATION_DESCRIPTION);
	}

	public WasStopApplicationStep(WasCluster cluster, EjbJar ejbJar) {
		super(cluster, (NamedDeployableArtifact) ejbJar, STOP_APPLICATION_COMMAND, STOP_APPLICATION_DESCRIPTION);
	}

	public WasStopApplicationStep(WasServer server, Ear ear) {
		super(server, (NamedDeployableArtifact) ear, STOP_APPLICATION_COMMAND, STOP_APPLICATION_DESCRIPTION);
	}

	public WasStopApplicationStep(WasServer server, War war) {
		super(server, (NamedDeployableArtifact) war, STOP_APPLICATION_COMMAND, STOP_APPLICATION_DESCRIPTION);
	}

	public WasStopApplicationStep(WasServer server, EjbJar ejbJar) {
		super(server, (NamedDeployableArtifact) ejbJar, STOP_APPLICATION_COMMAND, STOP_APPLICATION_DESCRIPTION);
	}

}
